grab.spider.service.base — Grab 0.6.41 documentation

# `grab.spider.service.base`

## Module Contents

### Classes

`ServiceWorker` |
`BaseService` |

### Attributes

`logger` |

grab.spider.service.base.logger

class grab.spider.service.base.ServiceWorker(fatal_error_queue: queue.Queue[grab.spider.interface.FatalErrorQueueItem], worker_callback: collections.abc.Callable[Ellipsis, Any])
  build_thread_name(worker_callback: collections.abc.Callable[Ellipsis, Any]) → str
  worker_callback_wrapper(callback: collections.abc.Callable[Ellipsis, Any]) → collections.abc.Callable[Ellipsis, None]
  start() → None
  stop() → None
  process_pause_signal() → None
  pause() → None
  resume() → None
  is_alive() → bool

class grab.spider.service.base.BaseService(fatal_error_queue: queue.Queue[grab.spider.interface.FatalErrorQueueItem])
  create_worker(worker_action: collections.abc.Callable[Ellipsis, None]) → ServiceWorker
  iterate_workers(objects: list[ServiceWorker]) → collections.abc.Iterable[ServiceWorker]
  start() → None
  stop() → None
  pause() → None
  resume() → None
  register_workers(*args: Any) → None
  is_busy() → bool
  is_alive() → bool